;; Generated package description from blist.el  -*- no-byte-compile: t -*-
(define-package "blist" "0.2.0.20220913.173909" "Display bookmarks in an ibuffer way" '((ilist "0.1") (emacs "24")) :commit "31b22a82dc8f5142b8a82ad2ce420200695df75b" :authors '(("Durand" . "durand@jsdurand.xyz")) :maintainer '("Durand" . "durand@jsdurand.xyz") :keywords '("convenience") :url "https://gitlab.com/mmemmew/blist")
